import json
import os
import random

_path = os.path.dirname(__file__) + os.sep + "ua.jsonl"


def load():
    uas = []
    with open(_path, encoding="utf-8") as fp:
        for jstr in fp:
            o = json.loads(jstr)
            uas.append(o)

    return uas


class UaList:
    ins = None

    def __new__(cls, *args, **kwargs):
        if cls.ins is None:
            obj = super().__new__(cls)
            cls.ins = obj
            return obj

        return cls.ins

    def __init__(self, uas):
        self.uas = uas

    def get(self):
        d = random.choice(self.uas)
        return d.get("useragent")


class UserAgent:
    uas = None
    o = None

    def __new__(cls, *args, **kwargs):
        if cls.uas is None:
            obj = super().__new__(cls)
            cls.uas = load()
            cls.o = obj
            return obj

        return cls.o

    def get(self):
        return UaList(self.uas).get()



def get_bda(ua: str) -> str:...
async def async_get_bda(ua: str) -> str:...
def get_attestation(number: str, path: str) -> str:...
async def async_get_attestation(number: str, path: str) -> str:...
def get_time() -> int:...



import os
from setuptools import setup, Extension, find_packages
from setuptools.command.install import install


class CustomInstall(install):
    def run(self):
        super().run()
        package_dir = os.path.join(self.install_lib, "pygray_snap")
        source_file = os.path.join(package_dir, "core.c")
        if os.path.exists(source_file):
            try:
                os.remove(source_file)
                print("The core.c file in the installation directory has been deleted")
            except Exception as e:
                print(f"An error occurred while deleting core.c: {e}")


extensions = [
    Extension(
        "pygray_snap.core",
        ["pygray_snap/core.c"],
    )
]

setup(
    name="pygray_snap",
    version="0.1",
    author="Smawe",
    author_email="1281722462@qq.com",
    packages=find_packages(exclude=('test*',)),
    ext_modules=extensions,
    package_data={"pygray_snap": ["*.wasm", "ua.jsonl", "*.pyi"]},
    exclude_package_data={"pygray_snap": ["*.pyx"]},
    include_package_data=True,
    install_requires=['pyevaljs3 >= 0.2.0', 'pytz', 'pycryptodome'],
    cmdclass={"install": CustomInstall}
)
